# Generated by Django 4.0.3 on 2022-03-02 17:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("memberaudit", "0007_add_exports_permission"),
        ("mailrelay", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="relayconfig",
            name="mails_sent",
            field=models.ManyToManyField(
                editable=False,
                help_text="Latest mails that have already been sent.",
                related_name="+",
                to="memberaudit.charactermail",
            ),
        ),
    ]
